==> canvacord-3.3.7.tar.gz: canvacord-3.3.7/src/canvacord/generators/hitler.py <==
from PIL import Image
from PIL import ImageFont
from PIL import ImageDraw
from PIL import ImageColor
import asyncio
import aiohttp
from random import randint
from io import BytesIO
import discord
from typing import Union
from canvacord.generators.versionchecker import checkversion

async def getavatar(user: Union[discord.User, discord.Member]) -> bytes:
    session = aiohttp.ClientSession(loop=asyncio.get_event_loop())
    disver = str(discord.__version__)
    if disver.startswith("1"):
        async with session.get(str(user.avatar_url)) as response:
            avatarbytes = await response.read()
        await session.close()
    elif disver.startswith("2"):
        async with session.get(str(user.server_avatar.url)) as response:
            avatarbytes = await response.read()
        await session.close()
    return avatarbytes

async def getbackground(background):
    session = aiohttp.ClientSession(loop=asyncio.get_event_loop())
    async with session.get("https://cdn.glitch.com/dff50ce1-3805-4fdb-a7a5-8cabd5e53756%2Fhitler.bmp?v=1628376587311") as response:
        backgroundbytes = await response.read()
    await session.close()
    return backgroundbytes

async def hitler(user):
        avatar = Image.open(BytesIO(await getavatar(user))).convert('RGBA').resize((140, 140))
        image = Image.open(BytesIO(await getbackground("hitler")))
        image.paste(avatar, (46, 43), avatar)
        image = image.convert('RGB')

        b = BytesIO()
        image.save(b, format='png')
        b.seek(0)
        await checkversion()
        return b

==> canvacord-3.4.1.tar.gz: canvacord-3.4.1/src/canvacord/generators/hitler.py <==
from PIL import Image
from PIL import ImageFont
from PIL import ImageDraw
from PIL import ImageColor
import asyncio
import aiohttp
from random import randint
from io import BytesIO
import discord
from typing import Union
from canvacord.generators.versionchecker import checkversion

async def getavatar(user: Union[discord.User, discord.Member]) -> bytes:
    session = aiohttp.ClientSession(loop=asyncio.get_event_loop())
    disver = str(discord.__version__)
    if disver.startswith("1"):
        async with session.get(str(user.avatar_url)) as response:
            avatarbytes = await response.read()
        await session.close()
    elif disver.startswith("2"):
        async with session.get(str(user.display_avatar.url)) as response:
            avatarbytes = await response.read()
        await session.close()
    return avatarbytes

async def getbackground(background):
    session = aiohttp.ClientSession(loop=asyncio.get_event_loop())
    async with session.get("https://cdn.glitch.com/dff50ce1-3805-4fdb-a7a5-8cabd5e53756%2Fhitler.bmp?v=1628376587311") as response:
        backgroundbytes = await response.read()
    await session.close()
    return backgroundbytes

async def hitler(user):
        avatar = Image.open(BytesIO(await getavatar(user))).convert('RGBA').resize((140, 140))
        image = Image.open(BytesIO(await getbackground("hitler")))
        image.paste(avatar, (46, 43), avatar)
        image = image.convert('RGB')

        b = BytesIO()
        image.save(b, format='png')
        b.seek(0)
        await checkversion()
        return b
